@@ -34,6 +34,7 @@ from SLOPpy.spectra_lightcurve_average import *
 from SLOPpy.transmission_lightcurve import *
 from SLOPpy.transmission_lightcurve_average import *
 from SLOPpy.write_output_spectra import *
+from SLOPpy.write_output_transmission import *
 
 from SLOPpy.quick_transmission import *
 
@@ -46,4 +47,4 @@ from SLOPpy.transmission_binned_mcmc import *
 from SLOPpy.pca_preparation import *
 from SLOPpy.sysrem_correction import *
 
-__version__ = "1.0.2"
+__version__ = "1.1"
