@@ -355,12 +355,10 @@ def compute_clv_rm_models_lines(config_in, lines_label):
 
             if n_oversampling % 2 == 0:
                 n_oversampling += 1
-            delta_step = observational_pams[obs]['EXPTIME'] / \
-                n_oversampling / 86400. / 2.
+            half_time = observational_pams[obs]['EXPTIME'] / 2 / 86400.
 
-            processed[obs]['bjd_oversampling'] = np.linspace(observational_pams[obs]['BJD'] - delta_step,
-                                                             observational_pams[obs]['BJD'] +
-                                                             delta_step,
+            processed[obs]['bjd_oversampling'] = np.linspace(observational_pams[obs]['BJD'] - half_time,
+                                                             observational_pams[obs]['BJD'] + half_time,
                                                              n_oversampling, dtype=np.double)
 
 
