@@ -130,6 +130,8 @@ def compute_spectra_lightcurve(config_in, lines_label):
                 input_data[obs]['wave'], input_data[obs]['e2ds'], input_data[obs]['e2ds_err'],
                 observational_pams['wavelength_rescaling'])
 
+            preserve_flux = input_data[obs].get('absolute_flux', True)
+
             preparation[obs]['rebinned'] = \
                 rebin_2d_to_1d(input_data[obs]['wave'],
                                input_data[obs]['step'],
@@ -137,6 +139,7 @@ def compute_spectra_lightcurve(config_in, lines_label):
                                calib_data['blaze'],
                                preparation['wave'],
                                preparation['step'],
+                               preserve_flux=preserve_flux,
                                rv_shift=observational_pams[obs]['rv_shift_ORF2SRF'])
 
             preparation[obs]['rebinned_err'] = \
@@ -146,6 +149,7 @@ def compute_spectra_lightcurve(config_in, lines_label):
                                calib_data['blaze'],
                                preparation['wave'],
                                preparation['step'],
+                               preserve_flux=preserve_flux,
                                rv_shift=observational_pams[obs]['rv_shift_ORF2SRF'])
 
 
